(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     97786,       2205]
NotebookOptionsPosition[     95711,       2132]
NotebookOutlinePosition[     96054,       2147]
CellTagsIndexPosition[     96011,       2144]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Periodic Properties", "Title",
 CellChangeTimes->{{3.5545599540369816`*^9, 3.5545599579901066`*^9}, 
   3.554815975953125*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TabView", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\"\<Welcome\>\"", "\[Rule]", 
       RowBox[{"Panel", "[", 
        RowBox[{"Column", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Periodic Properites\>\"", ",", "Bold", ",", "20"}], 
             "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Style", "[", 
             RowBox[{
             "\"\<      This activity displays a variety of elemental \
properties in graphical format.  It uses Mathematica's FreeCDF application \
along with Wolfram's ElementData curated data set. The Activity tab contains \
the meat of this application.  It is designed to be intuitive, but I've \
included some tooltips for good measure.  The Example tab contains two \
exercises that hopefully help in introducing you to the activity and how it \
can be used.  Finally, the legal tab has links to the Licensing terms of the \
activity (simply put, feel free to use it in your classroom) as well as \
contact information should you have a concern, criticism or compliment.\>\"", 
              ",", "14"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Style", "[", 
             RowBox[{
             "\"\<Written by BoB LeSuer\>\"", ",", "Bold", ",", "14"}], 
             "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
          RowBox[{"Spacings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "2"}], "}"}]}]}], "]"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<Example\>\"", "\[Rule]", "\[IndentingNewLine]", 
       RowBox[{"Panel", "[", 
        RowBox[{"Column", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Sample Exercises\>\"", ",", "Bold", ",", "20"}], 
             "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Style", "[", 
             RowBox[{
             "\"\<Exercise #1\\n(1) PREDICT what the plot of atomic radius \
versus atomic number will look like for the elements in the 4th row of the \
periodic table.\\n(2) On the Activity tab, make sure the \!\(\*
StyleBox[\"Use\",
FontVariations->{\"Underline\"->True}]\)\!\(\*
StyleBox[\" \",
FontVariations->{\"Underline\"->True}]\)\!\(\*
StyleBox[\"classes\",
FontVariations->{\"Underline\"->True}]\) checkbox is selected in the Atom \
Selection pane, then select \!\(\*
StyleBox[\"Period4elements\",
FontVariations->{\"Underline\"->True}]\) from the class menu.\\n(3) Select \!\
\(\*
StyleBox[\"AtomicNumber\",
FontVariations->{\"Underline\"->True}]\) for the x parameter and \!\(\*
StyleBox[\"AtomicRadius\",
FontVariations->{\"Underline\"->True}]\) for the y parameter.\\n(4) DESCRIBE \
what you observe.  Was your prediction in step 1 correct?\\n(5) EXPLAIN the \
trend.  If you need help, look in a chemistry textbook for the shielding \
effect.  You can also do a web search on that topic.\>\"", ",", "14"}], "]"}],
             ",", "\[IndentingNewLine]", 
            RowBox[{"Style", "[", 
             RowBox[{
             "\"\<Exercise #2\\n(1) PREDICT what the plot of atomic radius \
versus atomic number will look like for the elements in group 17: the \
halogens.\\n(2) On the Activity tab, change the selection in the class menu \
to halogen.\\n(3) DESCRIBE what you observe.  Was your prediction in step 1 \
correct?\\n(5) EXPLAIN the trend.  Can you combine the results from these two \
exercises to explain how the shielding effect influences the atomic radius?\>\
\"", ",", "14"}], "]"}]}], "}"}], ",", 
          RowBox[{"Dividers", "\[Rule]", "Center"}], ",", 
          RowBox[{"Spacings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "1"}], "}"}]}]}], "]"}], 
        "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<Activity\>\"", "\[Rule]", 
       RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Module", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"data", ",", "lm", ",", "subset"}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"subset", " ", "=", " ", 
             RowBox[{"If", "[", 
              RowBox[{"useclasses", ",", 
               RowBox[{"ElementData", "[", "whichclass", "]"}], ",", 
               RowBox[{"Range", "[", 
                RowBox[{"lowz", ",", "highz"}], "]"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"data", " ", "=", " ", 
             RowBox[{"DeleteCases", "[", 
              RowBox[{
               RowBox[{"Quiet", "@", 
                RowBox[{"Map", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Thread", "[", 
                    RowBox[{"ElementData", "[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"xaxis", ",", "yaxis", ",", "\"\<Symbol\>\""}], 
                    "}"}]}], "]"}], "]"}], "&"}], ",", "subset"}], "]"}]}], 
               ",", 
               RowBox[{"x_", "/;", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Head", "[", 
                   RowBox[{"x", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "]"}], "\[Equal]", 
                  "Missing"}], "||", 
                 RowBox[{
                  RowBox[{"Head", "[", 
                   RowBox[{"x", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "]"}], "\[Equal]", 
                  "Missing"}]}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "1"}], "]"}], "]"}], "=", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"xaxis", "\[Equal]", "\"\<IonizationEnergies\>\""}], 
               ",", 
               RowBox[{"First", "/@", 
                RowBox[{"data", "[", 
                 RowBox[{"[", 
                  RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ",", 
               RowBox[{"data", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "1"}], "]"}], "]"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "1"}], "]"}], "]"}], " ", "=", " ", 
             RowBox[{"xaxisfunction", "[", 
              RowBox[{"data", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "=", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"yaxis", "\[Equal]", "\"\<IonizationEnergies\>\""}], 
               ",", 
               RowBox[{"First", "/@", 
                RowBox[{"data", "[", 
                 RowBox[{"[", 
                  RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ",", 
               RowBox[{"data", "[", 
                RowBox[{"[", 
                 RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "2"}], "]"}], "]"}], "=", 
             RowBox[{"yaxisfunction", "[", 
              RowBox[{"data", "[", 
               RowBox[{"[", 
                RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"lm", " ", "=", " ", 
             RowBox[{"If", "[", 
              RowBox[{"fit", ",", 
               RowBox[{"LinearModelFit", "[", 
                RowBox[{
                 RowBox[{"data", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", "x", 
                 ",", "x"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{"fit", ",", "\[IndentingNewLine]", 
              RowBox[{"Plot", "[", 
               RowBox[{
                RowBox[{"Normal", "[", "lm", "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x", ",", 
                  RowBox[{"Min", "[", 
                   RowBox[{"data", "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
                  RowBox[{"Max", "[", 
                   RowBox[{"data", "[", 
                    RowBox[{"[", 
                    RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"Epilog", "\[Rule]", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"Point", "[", 
                    RowBox[{"data", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], "]"}], 
                    ",", 
                    RowBox[{"data", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", ",", "3"}], "]"}], "]"}]}], "]"}], "&"}], "/@", 
                   RowBox[{"Range", "[", 
                    RowBox[{"Length", "[", "data", "]"}], "]"}]}], ")"}]}], 
                ",", "\[IndentingNewLine]", 
                RowBox[{"Frame", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"True", ",", "True", ",", "False", ",", "False"}], 
                  "}"}]}], ",", 
                RowBox[{"FrameLabel", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"xaxis", ",", "yaxis"}], "}"}]}], ",", 
                RowBox[{"PlotRange", "\[Rule]", "plotrange"}], ",", 
                RowBox[{"Axes", "\[Rule]", "False"}], ",", 
                RowBox[{"PlotLabel", "\[Rule]", 
                 RowBox[{"\"\<y = \>\"", "<>", 
                  RowBox[{"ToString", "[", 
                   RowBox[{
                    RowBox[{"lm", "[", "\"\<BestFit\>\"", "]"}], " ", ",", 
                    RowBox[{"FormatType", "\[Rule]", "TraditionalForm"}]}], 
                   "]"}], "<>", 
                  "\"\<\\n\!\(\*SuperscriptBox[\(R\), \(2\)]\):\>\"", "<>", 
                  RowBox[{"ToString", "[", 
                   RowBox[{"N", "[", 
                    RowBox[{"lm", "[", "\"\<RSquared\>\"", "]"}], "]"}], 
                   "]"}]}]}]}], "]"}], ",", "\[IndentingNewLine]", 
              RowBox[{"ListPlot", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Tooltip", "[", 
                    RowBox[{
                    RowBox[{"data", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
                    RowBox[{"data", "[", 
                    RowBox[{"[", 
                    RowBox[{"#", ",", "3"}], "]"}], "]"}]}], "]"}], "&"}], "/@", 
                  RowBox[{"Range", "[", 
                   RowBox[{"Length", "[", "data", "]"}], "]"}]}], ")"}], ",", 
                RowBox[{"Frame", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"True", ",", "True", ",", "False", ",", "False"}], 
                  "}"}]}], ",", 
                RowBox[{"FrameLabel", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{"xaxis", ",", "yaxis"}], "}"}]}], ",", 
                RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
                RowBox[{"PlotRange", "\[Rule]", "plotrange"}], ",", 
                RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], 
             "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Tooltip", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<Atom selection\>\"", ",", "12", ",", "Bold"}], "]"}],
            ",", "\"\<There are two modes of Z selection: select a Z range or \
use a class of compounds.\>\""}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"useclasses", ",", "False", ",", "\"\<Use Classes?\>\""}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"lowz", ",", "1", ",", "\"\<Smallest Z\>\""}], "}"}], ",",
            "1", ",", 
           RowBox[{"highz", "-", "5"}], ",", "1", ",", 
           RowBox[{"Appearance", "\[Rule]", 
            RowBox[{"{", "\"\<Labeled\>\"", "}"}]}], ",", 
           RowBox[{"Enabled", "\[Rule]", 
            RowBox[{"!", "useclasses"}]}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"highz", ",", "102", ",", "\"\<Largest Z\>\""}], "}"}], 
           ",", 
           RowBox[{"lowz", "+", "5"}], ",", "102", ",", "1", ",", 
           RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
           RowBox[{"Enabled", " ", "\[Rule]", " ", 
            RowBox[{"!", "useclasses"}]}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "whichclass", ",", "\"\<Natural\>\"", ",", 
             "\"\<Choose class\>\""}], "}"}], ",", "classes", ",", 
           RowBox[{"Enabled", "\[Rule]", "useclasses"}]}], "}"}], ",", 
         "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
         RowBox[{"Tooltip", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<Miscellaneous\>\"", ",", "12", ",", "Bold"}], "]"}], 
           ",", "\"\<Choose whether or not to include a linear regression \
line.  Also, when some plots have 1 or two extraneous points, the Automatic \
mode ignores them.\>\""}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Row", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Control", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"fit", ",", "False", ",", "\"\<Linear Fit?\>\""}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"True", ",", "False"}], "}"}]}], "}"}], "]"}], ",", 
            "\"\<     \>\"", ",", 
            RowBox[{"Control", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                "plotrange", ",", "Automatic", ",", "\"\<Plot Range?\>\""}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"Automatic", ",", "All"}], "}"}]}], "}"}], "]"}]}], 
           "}"}], "]"}], ",", "\[IndentingNewLine]", "Delimiter", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Tooltip", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<Axis parameters and function to apply\>\"", ",", "12", ",", 
             "Bold"}], "]"}], ",", 
           "\"\<There are many parameters to choose from.  Unselecting 'Full \
parameter set' gives a list of 10 common parameters.  A log or inverse \
function can be applied to each axis.  Clicking on 'nofunc' gives the data as \
is.\>\""}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "xaxis", ",", "\"\<AtomicNumber\>\"", ",", 
             "\"\<X Parameter\>\""}], "}"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{"pset", ",", "properties", ",", "partproperties"}], "]"}],
            ",", 
           RowBox[{"ControlType", "\[Rule]", "PopupMenu"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"xaxisfunction", ",", "nofunc"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"nofunc", ",", "log", ",", "inverse"}], "}"}]}], "}"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "yaxis", ",", "\"\<AtomicWeight\>\"", ",", " ", 
             "\"\<Y Parameter\>\""}], "}"}], ",", 
           RowBox[{"If", "[", 
            RowBox[{"pset", ",", "properties", ",", "partproperties"}], "]"}],
            ",", 
           RowBox[{"ControlType", "\[Rule]", "PopupMenu"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"yaxisfunction", ",", "nofunc"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"nofunc", ",", "log", ",", "inverse"}], "}"}]}], "}"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"pset", ",", "True", ",", "\"\<Full Parameter Set?\>\""}],
             "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"ControlPlacement", "\[Rule]", "Bottom"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Initialization", ":>", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"properties", " ", "=", 
             RowBox[{"{", 
              RowBox[{
              "\"\<AtomicNumber\>\"", ",", "\"\<AtomicWeight\>\"", ",", 
               "\"\<AtomicRadius\>\"", ",", "\"\<CovalentRadius\>\"", ",", 
               "\"\<VanDerWaalsRadius\>\"", ",", "\"\<IonizationEnergies\>\"",
                ",", "\"\<ElectronAffinity\>\"", ",", 
               "\"\<Electronegativity\>\"", ",", "\"\<BrinellHardness\>\"", 
               ",", "\"\<BulkModulus\>\"", ",", "\"\<Density\>\"", ",", 
               "\"\<MohsHardness\>\"", ",", "\"\<MolarVolume\>\"", ",", 
               "\"\<PoissonRatio\>\"", ",", "\"\<ShearModulus\>\"", ",", 
               "\"\<SoundSpeed\>\"", ",", "\"\<ThermalConductivity\>\"", ",", 
               "\"\<ThermalExpansion\>\"", ",", "\"\<VickersHardness\>\"", 
               ",", "\"\<YoungModulus\>\"", ",", 
               "\"\<AbsoluteBoilingPoint\>\"", ",", 
               "\"\<AbsoluteMeltingPoint\>\"", ",", 
               "\"\<CriticalPressure\>\"", ",", "\"\<CriticalTemperature\>\"",
                ",", "\"\<FusionHeat\>\"", ",", "\"\<SpecificHeat\>\"", ",", 
               "\"\<VaporizationHeat\>\"", ",", 
               "\"\<ElectricalConductivity\>\"", ",", 
               "\"\<MassMagneticSusceptibility\>\"", ",", 
               "\"\<MolarMagneticSusceptibility\>\"", ",", 
               "\"\<Resistivity\>\"", ",", 
               "\"\<VolumeMagneticSusceptibility\>\"", ",", 
               "\"\<CrustAbundance\>\"", ",", "\"\<HumanAbundance\>\"", ",", 
               "\"\<MeteoriteAbundance\>\"", ",", "\"\<OceanAbundance\>\"", 
               ",", "\"\<SolarAbundance\>\"", ",", 
               "\"\<UniverseAbundance\>\"", ",", "\"\<DiscoveryYear\>\""}], 
              "}"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"partproperties", " ", "=", " ", 
             RowBox[{"{", 
              RowBox[{
              "\"\<AtomicNumber\>\"", ",", "\"\<AtomicWeight\>\"", ",", 
               "\"\<AtomicRadius\>\"", ",", "\"\<IonizationEnergies\>\"", ",",
                "\"\<ElectronAffinity\>\"", ",", "\"\<Electronegativity\>\"", 
               ",", "\"\<Density\>\"", ",", "\"\<AbsoluteBoilingPoint\>\"", 
               ",", "\"\<AbsoluteMeltingPoint\>\"", ",", 
               "\"\<UniverseAbundance\>\"", ",", "\"\<DiscoveryYear\>\""}], 
              "}"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"classes", " ", "=", " ", 
             RowBox[{"{", 
              RowBox[{
              "\"\<Natural\>\"", ",", "\"\<SBlock\>\"", ",", "\"\<PBlock\>\"",
                ",", "\"\<DBlock\>\"", ",", "\"\<FBlock\>\"", ",", 
               "\"\<AlkaliMetal\>\"", ",", "\"\<AlkalineEarthMetal\>\"", ",", 
               "\"\<Group13Elements\>\"", ",", "\"\<Group14Elements\>\"", 
               ",", "\"\<Group15Elements\>\"", ",", "\"\<Chalcogen\>\"", ",", 
               "\"\<Halogen\>\"", ",", "\"\<Period4Elements\>\""}], "}"}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"nofunc", "[", "x_", "]"}], ":=", "x"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"log", "[", "x_", "]"}], ":=", 
             RowBox[{"Log", "[", 
              RowBox[{"10", ",", "x"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"inverse", "[", "x_", "]"}], ":=", 
             SuperscriptBox["x", 
              RowBox[{"-", "1"}]]}], ";"}], "}"}]}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<Legal\>\"", "\[Rule]", 
       RowBox[{"Panel", "[", 
        RowBox[{"Column", "[", 
         RowBox[{
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{
             "\"\<Who did this? How? and Why?\>\"", ",", "Bold", ",", "20"}], 
             "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Style", "[", 
             RowBox[{
             "\"\<      BoB LeSuer; using Mathematica's FreeCDF; the tools \
were there.  I'm of the mindset that Chemistry is a far more tactile, visual \
and dynamic science than can be represented in a static textbook.\>\"", ",", 
              "14"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Can I use it?\>\"", ",", "Bold", ",", "20"}], "]"}],
             ",", "\[IndentingNewLine]", 
            RowBox[{"Style", "[", 
             RowBox[{
             "\"\<      Yes, please do.  The activity is freely available for \
use.  Wolfram's FreeCDF licensing terms can be found at the link below.  I'm \
happy to share the code with anyone interested; simply contact me.\>\"", ",", 
              "14"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Links\>\"", ",", "Bold", ",", "20"}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"Hyperlink", "[", 
               RowBox[{
               "\"\<Wolfram FreeCDF licensing terms\>\"", ",", 
                "\"\<Http://www.wolfram.com/cdf/adopting-cdf/licensing-\
options.html\>\""}], "]"}], ",", "14"}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Style", "[", 
             RowBox[{
              RowBox[{"Hyperlink", "[", 
               RowBox[{
               "\"\<My contact information\>\"", ",", 
                "\"\<http://www.csu.edu/chemistryandphysics/facultylesuer.htm\
\>\""}], "]"}], ",", "14"}], "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
          RowBox[{"Spacings", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Automatic", ",", "1"}], "}"}]}]}], "]"}], "]"}]}]}], 
     "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"ControlPlacement", "\[Rule]", "Left"}], ",", 
    RowBox[{"ImageSize", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"500", ",", "700"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.5545639183651066`*^9, 3.5545639186151066`*^9}, {
   3.5545640743651066`*^9, 3.5545641612088566`*^9}, {3.5545674205682316`*^9, 
   3.5545674243338566`*^9}, {3.5545674773026066`*^9, 
   3.5545674806932316`*^9}, {3.5545679244432316`*^9, 
   3.5545679841307316`*^9}, {3.5545680452713566`*^9, 3.5545681198807316`*^9}, 
   3.5545701803807316`*^9, {3.55465439489625*^9, 3.554654517693125*^9}, {
   3.554654557615*^9, 3.554654569505625*^9}, {3.554654613349375*^9, 
   3.554654650115*^9}, {3.554654901286875*^9, 3.55465506220875*^9}, {
   3.5546550951775*^9, 3.5546551408025*^9}, {3.55465546524*^9, 
   3.554655751005625*^9}, {3.55480437553125*^9, 3.5548044114375*^9}, {
   3.554804469046875*^9, 3.55480461265625*^9}, {3.5548047595*^9, 
   3.554804829359375*^9}, {3.554804886671875*^9, 3.5548048893125*^9}, {
   3.55480534809375*^9, 3.55480541159375*^9}, {3.554809809546875*^9, 
   3.55480981584375*^9}, {3.55480994946875*^9, 3.554810149609375*^9}, {
   3.55481027171875*^9, 3.554810297328125*^9}, {3.554810721765625*^9, 
   3.554810901640625*^9}, 3.5548109338125*^9, {3.5548109645625*^9, 
   3.554811006359375*^9}, {3.554811041015625*^9, 3.55481108584375*^9}, {
   3.554811161265625*^9, 3.554811186515625*^9}, {3.554811238765625*^9, 
   3.554811300171875*^9}, {3.554812515203125*^9, 3.5548125206875*^9}, {
   3.554813593875*^9, 3.554813604140625*^9}, {3.554814795703125*^9, 
   3.554814821734375*^9}, 3.5548152565*^9, 3.554815918703125*^9, {
   3.557138832515625*^9, 3.557138832765625*^9}, {3.557139329765625*^9, 
   3.557139330390625*^9}, {3.557139396140625*^9, 3.5571394319375*^9}, {
   3.557139523640625*^9, 3.5571395261875*^9}}],

Cell[BoxData[
 TabViewBox[{{1,"\<\"Welcome\"\>"->
  PanelBox[
   TagBox[GridBox[{
      {
       StyleBox["\<\"Periodic Properites\"\>",
        StripOnInput->False,
        FontSize->20,
        FontWeight->Bold]},
      {
       StyleBox["\<\"      This activity displays a variety of elemental \
properties in graphical format.  It uses Mathematica's FreeCDF application \
along with Wolfram's ElementData curated data set. The Activity tab contains \
the meat of this application.  It is designed to be intuitive, but I've \
included some tooltips for good measure.  The Example tab contains two \
exercises that hopefully help in introducing you to the activity and how it \
can be used.  Finally, the legal tab has links to the Licensing terms of the \
activity (simply put, feel free to use it in your classroom) as well as \
contact information should you have a concern, criticism or compliment.\"\>",
        StripOnInput->False,
        FontSize->14]},
      {
       StyleBox["\<\"Written by BoB LeSuer\"\>",
        StripOnInput->False,
        FontSize->14,
        FontWeight->Bold]}
     },
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
     GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{2}}}],
    "Column"]]}, {2,"\<\"Example\"\>"->
  PanelBox[
   TagBox[GridBox[{
      {
       StyleBox["\<\"Sample Exercises\"\>",
        StripOnInput->False,
        FontSize->20,
        FontWeight->Bold]},
      {
       StyleBox["\<\"Exercise #1\\n(1) PREDICT what the plot of atomic radius \
versus atomic number will look like for the elements in the 4th row of the \
periodic table.\\n(2) On the Activity tab, make sure the \
\\!\\(\\*\\nStyleBox[\\\"Use\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\\!\\(\\*\\nStyleBox[\\\"\
classes\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\) checkbox is \
selected in the Atom Selection pane, then select \
\\!\\(\\*\\nStyleBox[\\\"Period4elements\\\",\\nFontVariations->{\\\"\
Underline\\\"->True}]\\) from the class menu.\\n(3) Select \
\\!\\(\\*\\nStyleBox[\\\"AtomicNumber\\\",\\nFontVariations->{\\\"Underline\\\
\"->True}]\\) for the x parameter and \\!\\(\\*\\nStyleBox[\\\"AtomicRadius\\\
\",\\nFontVariations->{\\\"Underline\\\"->True}]\\) for the y \
parameter.\\n(4) DESCRIBE what you observe.  Was your prediction in step 1 \
correct?\\n(5) EXPLAIN the trend.  If you need help, look in a chemistry \
textbook for the shielding effect.  You can also do a web search on that \
topic.\"\>",
        StripOnInput->False,
        FontSize->14]},
      {
       StyleBox["\<\"Exercise #2\\n(1) PREDICT what the plot of atomic radius \
versus atomic number will look like for the elements in group 17: the \
halogens.\\n(2) On the Activity tab, change the selection in the class menu \
to halogen.\\n(3) DESCRIBE what you observe.  Was your prediction in step 1 \
correct?\\n(5) EXPLAIN the trend.  Can you combine the results from these two \
exercises to explain how the shielding effect influences the atomic radius?\"\
\>",
        StripOnInput->False,
        FontSize->14]}
     },
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxDividers->{
      "Columns" -> {False, {True}, False}, "Rows" -> {False, {True}, False}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
     GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
    "Column"]]}, {3,"\<\"Activity\"\>"->
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`fit$$ = False, $CellContext`highz$$ = 
     41., $CellContext`lowz$$ = 1, $CellContext`plotrange$$ = 
     Automatic, $CellContext`pset$$ = False, $CellContext`useclasses$$ = 
     False, $CellContext`whichclass$$ = "Natural", $CellContext`xaxis$$ = 
     "AtomicNumber", $CellContext`xaxisfunction$$ = $CellContext`nofunc, \
$CellContext`yaxis$$ = 
     "Density", $CellContext`yaxisfunction$$ = $CellContext`nofunc, 
     Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
     Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
     1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
       Hold[
        Tooltip[
         Style["Atom selection", 12, Bold], 
         "There are two modes of Z selection: select a Z range or use a class \
of compounds."]], Manipulate`Dump`ThisIsNotAControl}, {{
        Hold[$CellContext`useclasses$$], False, "Use Classes?"}, {
       True, False}}, {{
        Hold[$CellContext`lowz$$], 1, "Smallest Z"}, 1, 
       Dynamic[$CellContext`highz$$ - 5], 1}, {{
        Hold[$CellContext`highz$$], 102, "Largest Z"}, 
       Dynamic[$CellContext`lowz$$ + 5], 102, 1}, {{
        Hold[$CellContext`whichclass$$], "Natural", "Choose class"}, {
       "Natural", "SBlock", "PBlock", "DBlock", "FBlock", "AlkaliMetal", 
        "AlkalineEarthMetal", "Group13Elements", "Group14Elements", 
        "Group15Elements", "Chalcogen", "Halogen", "Period4Elements"}}, {
       Hold[
        Tooltip[
         Style["Miscellaneous", 12, Bold], 
         "Choose whether or not to include a linear regression line.  Also, \
when some plots have 1 or two extraneous points, the Automatic mode ignores \
them."]], Manipulate`Dump`ThisIsNotAControl}, {{
        Hold[$CellContext`fit$$], False, "Linear Fit?"}, {True, False}}, {{
        Hold[$CellContext`plotrange$$], Automatic, "Plot Range?"}, {
       Automatic, All}}, {
       Hold[
        Row[{
          Manipulate`Place[1], "     ", 
          Manipulate`Place[2]}]], Manipulate`Dump`ThisIsNotAControl}, {
       Hold[
        Tooltip[
         Style["Axis parameters and function to apply", 12, Bold], 
         "There are many parameters to choose from.  Unselecting 'Full \
parameter set' gives a list of 10 common parameters.  A log or inverse \
function can be applied to each axis.  Clicking on 'nofunc' gives the data as \
is."]], Manipulate`Dump`ThisIsNotAControl}, {{
        Hold[$CellContext`xaxis$$], "AtomicNumber", "X Parameter"}, 
       Dynamic[
        If[$CellContext`pset$$, $CellContext`properties, \
$CellContext`partproperties]]}, {{
        Hold[$CellContext`xaxisfunction$$], $CellContext`nofunc}, \
{$CellContext`nofunc, $CellContext`log, $CellContext`inverse}}, {{
        Hold[$CellContext`yaxis$$], "AtomicWeight", "Y Parameter"}, 
       Dynamic[
        If[$CellContext`pset$$, $CellContext`properties, \
$CellContext`partproperties]]}, {{
        Hold[$CellContext`yaxisfunction$$], $CellContext`nofunc}, \
{$CellContext`nofunc, $CellContext`log, $CellContext`inverse}}, {{
        Hold[$CellContext`pset$$], True, "Full Parameter Set?"}, {
       True, False}}}, Typeset`size$$ = {360., {113., 118.}}, 
     Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
     False, $CellContext`useclasses$15213$$ = 
     False, $CellContext`lowz$15214$$ = 0, $CellContext`highz$15215$$ = 
     0, $CellContext`whichclass$15216$$ = 0, $CellContext`fit$15217$$ = 
     False, $CellContext`plotrange$15218$$ = 
     False, $CellContext`xaxisfunction$15219$$ = 
     0, $CellContext`yaxisfunction$15220$$ = 0, $CellContext`pset$15221$$ = 
     False}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      2, StandardForm, 
       "Variables" :> {$CellContext`fit$$ = False, $CellContext`highz$$ = 
         102, $CellContext`lowz$$ = 1, $CellContext`plotrange$$ = 
         Automatic, $CellContext`pset$$ = True, $CellContext`useclasses$$ = 
         False, $CellContext`whichclass$$ = "Natural", $CellContext`xaxis$$ = 
         "AtomicNumber", $CellContext`xaxisfunction$$ = $CellContext`nofunc, \
$CellContext`yaxis$$ = 
         "AtomicWeight", $CellContext`yaxisfunction$$ = $CellContext`nofunc}, 
       "ControllerVariables" :> {
         Hold[$CellContext`useclasses$$, $CellContext`useclasses$15213$$, 
          False], 
         Hold[$CellContext`lowz$$, $CellContext`lowz$15214$$, 0], 
         Hold[$CellContext`highz$$, $CellContext`highz$15215$$, 0], 
         Hold[$CellContext`whichclass$$, $CellContext`whichclass$15216$$, 0], 
         Hold[$CellContext`fit$$, $CellContext`fit$15217$$, False], 
         Hold[$CellContext`plotrange$$, $CellContext`plotrange$15218$$, 
          False], 
         Hold[$CellContext`xaxisfunction$$, \
$CellContext`xaxisfunction$15219$$, 0], 
         Hold[$CellContext`yaxisfunction$$, \
$CellContext`yaxisfunction$15220$$, 0], 
         Hold[$CellContext`pset$$, $CellContext`pset$15221$$, False]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, "Body" :> 
       Module[{$CellContext`data$, $CellContext`lm$, $CellContext`subset$}, \
$CellContext`subset$ = If[$CellContext`useclasses$$, 
            ElementData[$CellContext`whichclass$$], 
            
            Range[$CellContext`lowz$$, $CellContext`highz$$]]; \
$CellContext`data$ = DeleteCases[
            Quiet[
             Map[Thread[
               
               ElementData[#, {$CellContext`xaxis$$, $CellContext`yaxis$$, 
                 "Symbol"}]]& , $CellContext`subset$]], 
            Condition[
             Pattern[$CellContext`x, 
              Blank[]], 
             Or[Head[
                Part[$CellContext`x, 1]] == Missing, Head[
                Part[$CellContext`x, 2]] == Missing]]]; 
         Part[$CellContext`data$, All, 1] = 
          If[$CellContext`xaxis$$ == "IonizationEnergies", 
            Map[First, 
             Part[$CellContext`data$, All, 1]], 
            Part[$CellContext`data$, All, 1]]; 
         Part[$CellContext`data$, All, 1] = $CellContext`xaxisfunction$$[
            Part[$CellContext`data$, All, 1]]; 
         Part[$CellContext`data$, All, 2] = 
          If[$CellContext`yaxis$$ == "IonizationEnergies", 
            Map[First, 
             Part[$CellContext`data$, All, 2]], 
            Part[$CellContext`data$, All, 2]]; 
         Part[$CellContext`data$, All, 2] = $CellContext`yaxisfunction$$[
            Part[$CellContext`data$, All, 2]]; $CellContext`lm$ = 
          If[$CellContext`fit$$, 
            LinearModelFit[
             
             Part[$CellContext`data$, All, {1, 
              2}], $CellContext`x, $CellContext`x]]; If[$CellContext`fit$$, 
           Plot[
            Normal[$CellContext`lm$], {$CellContext`x, 
             Min[
              Part[$CellContext`data$, All, 1]], 
             Max[
              Part[$CellContext`data$, All, 1]]}, Epilog -> Map[Tooltip[
               Point[
                Part[$CellContext`data$, #, {1, 2}]], 
               Part[$CellContext`data$, #, 3]]& , 
              Range[
               Length[$CellContext`data$]]], 
            Frame -> {True, True, False, False}, 
            FrameLabel -> {$CellContext`xaxis$$, $CellContext`yaxis$$}, 
            PlotRange -> $CellContext`plotrange$$, Axes -> False, PlotLabel -> 
            StringJoin["y = ", 
              ToString[
               $CellContext`lm$["BestFit"], FormatType -> TraditionalForm], 
              "\n\!\(\*SuperscriptBox[\(R\), \(2\)]\):", 
              ToString[
               N[
                $CellContext`lm$["RSquared"]]]]], 
           ListPlot[
            Map[Tooltip[
              Part[$CellContext`data$, #, {1, 2}], 
              Part[$CellContext`data$, #, 3]]& , 
             Range[
              Length[$CellContext`data$]]], 
            Frame -> {True, True, False, False}, 
            FrameLabel -> {$CellContext`xaxis$$, $CellContext`yaxis$$}, 
            Filling -> Axis, PlotRange -> $CellContext`plotrange$$, Axes -> 
            False]]], "Specifications" :> {
         Tooltip[
          Style["Atom selection", 12, Bold], 
          
          "There are two modes of Z selection: select a Z range or use a \
class of compounds."], {{$CellContext`useclasses$$, False, "Use Classes?"}, {
          True, False}}, {{$CellContext`lowz$$, 1, "Smallest Z"}, 1, 
          Dynamic[$CellContext`highz$$ - 5], 1, Appearance -> {"Labeled"}, 
          Enabled -> Dynamic[
            Not[$CellContext`useclasses$$]]}, {{$CellContext`highz$$, 102, 
           "Largest Z"}, 
          Dynamic[$CellContext`lowz$$ + 5], 102, 1, Appearance -> "Labeled", 
          Enabled -> Dynamic[
            Not[$CellContext`useclasses$$]]}, {{$CellContext`whichclass$$, 
           "Natural", "Choose class"}, {
          "Natural", "SBlock", "PBlock", "DBlock", "FBlock", "AlkaliMetal", 
           "AlkalineEarthMetal", "Group13Elements", "Group14Elements", 
           "Group15Elements", "Chalcogen", "Halogen", "Period4Elements"}, 
          Enabled -> Dynamic[$CellContext`useclasses$$]}, Delimiter, 
         Tooltip[
          Style["Miscellaneous", 12, Bold], 
          "Choose whether or not to include a linear regression line.  Also, \
when some plots have 1 or two extraneous points, the Automatic mode ignores \
them."], {{$CellContext`fit$$, False, "Linear Fit?"}, {True, False}, 
          ControlPlacement -> 
          1}, {{$CellContext`plotrange$$, Automatic, "Plot Range?"}, {
          Automatic, All}, ControlPlacement -> 2}, 
         Row[{
           Manipulate`Place[1], "     ", 
           Manipulate`Place[2]}], Delimiter, 
         Tooltip[
          Style["Axis parameters and function to apply", 12, Bold], 
          "There are many parameters to choose from.  Unselecting 'Full \
parameter set' gives a list of 10 common parameters.  A log or inverse \
function can be applied to each axis.  Clicking on 'nofunc' gives the data as \
is."], {{$CellContext`xaxis$$, "AtomicNumber", "X Parameter"}, 
          Dynamic[
           
           If[$CellContext`pset$$, $CellContext`properties, \
$CellContext`partproperties]], ControlType -> 
          PopupMenu}, {{$CellContext`xaxisfunction$$, $CellContext`nofunc}, \
{$CellContext`nofunc, $CellContext`log, $CellContext`inverse}}, \
{{$CellContext`yaxis$$, "AtomicWeight", "Y Parameter"}, 
          Dynamic[
           
           If[$CellContext`pset$$, $CellContext`properties, \
$CellContext`partproperties]], ControlType -> 
          PopupMenu}, {{$CellContext`yaxisfunction$$, $CellContext`nofunc}, \
{$CellContext`nofunc, $CellContext`log, $CellContext`inverse}}, \
{{$CellContext`pset$$, True, "Full Parameter Set?"}, {True, False}}}, 
       "Options" :> {ContinuousAction -> False, ControlPlacement -> Bottom}, 
       "DefaultOptions" :> {}],
      ImageSizeCache->{407., {297., 302.}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     Initialization:>({$CellContext`properties = {
          "AtomicNumber", "AtomicWeight", "AtomicRadius", "CovalentRadius", 
           "VanDerWaalsRadius", "IonizationEnergies", "ElectronAffinity", 
           "Electronegativity", "BrinellHardness", "BulkModulus", "Density", 
           "MohsHardness", "MolarVolume", "PoissonRatio", "ShearModulus", 
           "SoundSpeed", "ThermalConductivity", "ThermalExpansion", 
           "VickersHardness", "YoungModulus", "AbsoluteBoilingPoint", 
           "AbsoluteMeltingPoint", "CriticalPressure", "CriticalTemperature", 
           "FusionHeat", "SpecificHeat", "VaporizationHeat", 
           "ElectricalConductivity", "MassMagneticSusceptibility", 
           "MolarMagneticSusceptibility", "Resistivity", 
           "VolumeMagneticSusceptibility", "CrustAbundance", "HumanAbundance",
            "MeteoriteAbundance", "OceanAbundance", "SolarAbundance", 
           "UniverseAbundance", 
           "DiscoveryYear"}; $CellContext`partproperties = {
          "AtomicNumber", "AtomicWeight", "AtomicRadius", 
           "IonizationEnergies", "ElectronAffinity", "Electronegativity", 
           "Density", "AbsoluteBoilingPoint", "AbsoluteMeltingPoint", 
           "UniverseAbundance", "DiscoveryYear"}; $CellContext`classes = {
          "Natural", "SBlock", "PBlock", "DBlock", "FBlock", "AlkaliMetal", 
           "AlkalineEarthMetal", "Group13Elements", "Group14Elements", 
           "Group15Elements", "Chalcogen", "Halogen", 
           "Period4Elements"}; $CellContext`nofunc[
           Pattern[$CellContext`x, 
            Blank[]]] := $CellContext`x; $CellContext`log[
           Pattern[$CellContext`x, 
            Blank[]]] := Log[10, $CellContext`x]; $CellContext`inverse[
           Pattern[$CellContext`x, 
            Blank[]]] := $CellContext`x^(-1); Null}; 
      Typeset`initDone$$ = True),
     SynchronousInitialization->True,
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]]}, {4,"\<\"Legal\"\>"->
  PanelBox[
   TagBox[GridBox[{
      {
       StyleBox["\<\"Who did this? How? and Why?\"\>",
        StripOnInput->False,
        FontSize->20,
        FontWeight->Bold]},
      {
       StyleBox["\<\"      BoB LeSuer; using Mathematica's FreeCDF; the tools \
were there.  I'm of the mindset that Chemistry is a far more tactile, visual \
and dynamic science than can be represented in a static textbook.\"\>",
        StripOnInput->False,
        FontSize->14]},
      {
       StyleBox["\<\"Can I use it?\"\>",
        StripOnInput->False,
        FontSize->20,
        FontWeight->Bold]},
      {
       StyleBox["\<\"      Yes, please do.  The activity is freely available \
for use.  Wolfram's FreeCDF licensing terms can be found at the link below.  \
I'm happy to share the code with anyone interested; simply contact me.\"\>",
        StripOnInput->False,
        FontSize->14]},
      {
       StyleBox["\<\"Links\"\>",
        StripOnInput->False,
        FontSize->20,
        FontWeight->Bold]},
      {
       StyleBox[
        TagBox[
         ButtonBox[
          
          PaneSelectorBox[{False->"\<\"Wolfram FreeCDF licensing terms\"\>", 
           True->
           StyleBox["\<\"Wolfram FreeCDF licensing terms\"\>", 
            "HyperlinkActive"]}, Dynamic[
            CurrentValue["MouseOver"]],
           BaseStyle->{"Hyperlink"},
           BaselinePosition->Baseline,
           FrameMargins->0,
           ImageSize->Automatic],
          BaseStyle->"Hyperlink",
          ButtonData->{
            URL[
            "Http://www.wolfram.com/cdf/adopting-cdf/licensing-options.html"],
             None},
          
          ButtonNote->
           "Http://www.wolfram.com/cdf/adopting-cdf/licensing-options.html"],
         Annotation[#, 
          "Http://www.wolfram.com/cdf/adopting-cdf/licensing-options.html", 
          "Hyperlink"]& ],
        StripOnInput->False,
        FontSize->14]},
      {
       StyleBox[
        TagBox[
         ButtonBox[
          PaneSelectorBox[{False->"\<\"My contact information\"\>", True->
           StyleBox["\<\"My contact information\"\>", "HyperlinkActive"]}, 
           Dynamic[
            CurrentValue["MouseOver"]],
           BaseStyle->{"Hyperlink"},
           BaselinePosition->Baseline,
           FrameMargins->0,
           ImageSize->Automatic],
          BaseStyle->"Hyperlink",
          ButtonData->{
            URL["http://www.csu.edu/chemistryandphysics/facultylesuer.htm"], 
            None},
          
          ButtonNote->
           "http://www.csu.edu/chemistryandphysics/facultylesuer.htm"],
         Annotation[#, 
          "http://www.csu.edu/chemistryandphysics/facultylesuer.htm", 
          "Hyperlink"]& ],
        StripOnInput->False,
        FontSize->14]}
     },
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
     GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
    "Column"]]}}, 3,
  ControlPlacement->Left,
  ImageSize->{500, 700}]], "Output",
 CellChangeTimes->{{3.55481360546875*^9, 3.554813622734375*^9}, {
  3.554814799171875*^9, 3.55481483725*^9}, {3.5548152578125*^9, 
  3.554815297375*^9}, {3.554815921515625*^9, 3.554815954578125*^9}, {
  3.557138714625*^9, 3.557138731703125*^9}, {3.557138794640625*^9, 
  3.557138801296875*^9}, {3.55713883434375*^9, 3.557138839578125*^9}, {
  3.557138871671875*^9, 3.557138890796875*^9}, {3.557139317921875*^9, 
  3.557139338015625*^9}, {3.55713940340625*^9, 3.557139434453125*^9}, {
  3.5571395274375*^9, 3.557139530265625*^9}, {3.55713997*^9, 
  3.557139971171875*^9}, {3.557140592609375*^9, 3.55714059315625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["sandbox", "Subsubsection",
 CellChangeTimes->{{3.5548125904375*^9, 3.554812593078125*^9}}],

Cell[BoxData[
 RowBox[{"properties", "=."}]], "Input",
 CellChangeTimes->{{3.5545679881932316`*^9, 3.5545679903963566`*^9}}],

Cell[BoxData["hyperlink"], "Input",
 CellChangeTimes->{{3.55481094684375*^9, 3.55481094775*^9}}],

Cell[BoxData[
 RowBox[{"classes", "=."}]], "Input",
 CellChangeTimes->{{3.554810313984375*^9, 3.554810316203125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ElementData", "[", "\"\<Classes\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.55465475924*^9, 3.554654787130625*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Actinide\"\>", ",", "\<\"AlkaliMetal\"\>", 
   ",", "\<\"AlkalineEarthMetal\"\>", ",", "\<\"Antiferromagnetic\"\>", 
   ",", "\<\"Chalcogen\"\>", ",", "\<\"Conductor\"\>", ",", "\<\"DBlock\"\>", 
   ",", "\<\"Diamagnetic\"\>", ",", "\<\"FBlock\"\>", 
   ",", "\<\"Ferromagnetic\"\>", ",", "\<\"Gas\"\>", 
   ",", "\<\"Group10Elements\"\>", ",", "\<\"Group11Elements\"\>", 
   ",", "\<\"Group12Elements\"\>", ",", "\<\"Group13Elements\"\>", 
   ",", "\<\"Group14Elements\"\>", ",", "\<\"Group15Elements\"\>", 
   ",", "\<\"Group16Elements\"\>", ",", "\<\"Group17Elements\"\>", 
   ",", "\<\"Group18Elements\"\>", ",", "\<\"Group1Elements\"\>", 
   ",", "\<\"Group2Elements\"\>", ",", "\<\"Group3Elements\"\>", 
   ",", "\<\"Group4Elements\"\>", ",", "\<\"Group5Elements\"\>", 
   ",", "\<\"Group6Elements\"\>", ",", "\<\"Group7Elements\"\>", 
   ",", "\<\"Group8Elements\"\>", ",", "\<\"Group9Elements\"\>", 
   ",", "\<\"Halogen\"\>", ",", "\<\"Insulator\"\>", 
   ",", "\<\"Lanthanide\"\>", ",", "\<\"Liquid\"\>", ",", "\<\"Metal\"\>", 
   ",", "\<\"Metalloid\"\>", ",", "\<\"Natural\"\>", ",", "\<\"NobleGas\"\>", 
   ",", "\<\"Nonmetal\"\>", ",", "\<\"Paramagnetic\"\>", 
   ",", "\<\"PBlock\"\>", ",", "\<\"Period1Elements\"\>", 
   ",", "\<\"Period2Elements\"\>", ",", "\<\"Period3Elements\"\>", 
   ",", "\<\"Period4Elements\"\>", ",", "\<\"Period5Elements\"\>", 
   ",", "\<\"Period6Elements\"\>", ",", "\<\"Period7Elements\"\>", 
   ",", "\<\"PoorMetal\"\>", ",", "\<\"Radioactive\"\>", 
   ",", "\<\"RareEarthMetal\"\>", ",", "\<\"SBlock\"\>", 
   ",", "\<\"Semiconductor\"\>", ",", "\<\"Solid\"\>", ",", "\<\"Stable\"\>", 
   ",", "\<\"Synthetic\"\>", ",", "\<\"TransitionMetal\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.554654787443125*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.554658150411875*^9, 3.5546581509275*^9}, {
  3.554804960359375*^9, 3.5548049630625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ElementData", "[", 
     RowBox[{"#", ",", "\"\<AtomicNumber\>\""}], "]"}], "&"}], "/@", 
   RowBox[{"ElementData", "[", "\"\<All\>\"", "]"}]}], "//", 
  "Sort"}]], "Input",
 CellChangeTimes->{{3.554804988765625*^9, 3.554804991296875*^9}, {
  3.554805036078125*^9, 3.5548050830625*^9}, {3.554805153078125*^9, 
  3.55480515365625*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ElementData", "::", "notent"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\\"\\\\\\\"All\\\\\\\"\\\"\\)\[NoBreak] \
is not a known entity, class, or tag for \[NoBreak]\\!\\(ElementData\\)\
\[NoBreak]. Use \[NoBreak]\\!\\(ElementData\\)\[NoBreak][] for a list of \
entities. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/ElementData\\\", ButtonNote -> \
\\\"ElementData::notent\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.554805154015625*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ElementData", "::", "notent"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\\"\\\\\\\"All\\\\\\\"\\\"\\)\[NoBreak] \
is not a known entity, class, or tag for \[NoBreak]\\!\\(ElementData\\)\
\[NoBreak]. Use \[NoBreak]\\!\\(ElementData\\)\[NoBreak][] for a list of \
entities. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/ElementData\\\", ButtonNote -> \
\\\"ElementData::notent\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.55480515403125*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ElementData", "::", "notent"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\\"ElementData[\\\\\\\"All\\\\\\\", \
\\\\\\\"AtomicNumber\\\\\\\"]\\\"\\)\[NoBreak] is not a known entity, class, \
or tag for \[NoBreak]\\!\\(ElementData\\)\[NoBreak]. Use \
\[NoBreak]\\!\\(ElementData\\)\[NoBreak][] for a list of entities. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/ElementData\\\", ButtonNote -> \
\\\"ElementData::notent\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.55480515403125*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \
\[NoBreak]\\!\\(\\*StyleBox[\\(ElementData :: notent\\), \\\"MessageName\\\"]\
\\)\[NoBreak] will be suppressed during this calculation. \\!\\(\\*ButtonBox[\
\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.55480515403125*^9}],

Cell[BoxData[
 RowBox[{"ElementData", "[", 
  RowBox[{"ElementData", "[", 
   RowBox[{"\<\"All\"\>", ",", "\<\"AtomicNumber\"\>"}], "]"}], 
  "]"}]], "Output",
 CellChangeTimes->{{3.554805043296875*^9, 3.55480508334375*^9}, 
   3.55480515403125*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"classes", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
   "\"\<Natural\>\"", ",", "\"\<SBlock\>\"", ",", "\"\<PBlock\>\"", ",", 
    "\"\<DBLock\>\"", ",", "\"\<FBlock\>\"", ",", "\"\<AlkaliMetal\>\"", ",", 
    "\"\<AlkalineEarthMetal\>\"", ",", "\"\<Group13Elements\>\"", ",", 
    "\"\<Group14Elements\>\"", ",", "\"\<Group15Elements\>\"", ",", 
    "\"\<Chalcogen\>\"", ",", "\"\<Halogen\>\"", ",", 
    "\"\<Period4Elements\>\""}], "}"}]}]], "Input",
 CellChangeTimes->{{3.554805174265625*^9, 3.554805249578125*^9}, {
  3.554805283625*^9, 3.55480533234375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"Hyperlink", "[", 
   RowBox[{"\"\<test\>\"", ",", "\"\<www.google.com\>\""}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.554811318296875*^9, 3.55481133234375*^9}}],

Cell[BoxData["Hyperlink"], "Output",
 CellChangeTimes->{3.5548113329375*^9}]
}, Open  ]],

Cell[BoxData["ToString"], "Input",
 CellChangeTimes->{{3.554811393140625*^9, 3.5548113941875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Welcome tab", "Subsubsection",
 CellChangeTimes->{{3.554812557515625*^9, 3.554812558890625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Panel", "[", 
  RowBox[{"Column", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Periodic Properites\>\"", ",", "Bold", ",", "20"}], "]"}],
       ",", "\[IndentingNewLine]", 
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<      This activity displays a variety of elemental properties in \
graphical format.  It uses Mathematica's FreeCDF application along with \
Wolfram's ElementData curated data set. The Activity tab contains the meat of \
this application.  It is designed to be intuitive, but I've included some \
tooltips for good measure.  The Example tab contains two exercises that \
hopefully help in introducing you to the activity and how it can be used.  \
Finally, the legal tab has links to the Licensing terms of the activity \
(simply put, feel free to use it in your classroom) as well as contact \
information should you have a concern, criticism or compliment.\>\"", ",", 
        "14"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Written by BoB LeSuer\>\"", ",", "Bold", ",", "14"}], 
       "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Spacings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "2"}], "}"}]}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.55481145234375*^9, 3.554811561390625*^9}, {
  3.554814850359375*^9, 3.554815238234375*^9}}],

Cell[BoxData[
 PanelBox[
  TagBox[GridBox[{
     {
      StyleBox["\<\"Periodic Properites\"\>",
       StripOnInput->False,
       FontSize->20,
       FontWeight->Bold]},
     {
      StyleBox["\<\"      This activity displays a variety of elemental \
properties in graphical format.  It uses Mathematica's FreeCDF application \
along with Wolfram's ElementData curated data set. The Activity tab contains \
the meat of this application.  It is designed to be intuitive, but I've \
included some tooltips for good measure.  The Example tab contains two \
exercises that hopefully help in introducing you to the activity and how it \
can be used.  Finally, the legal tab has links to the Licensing terms of the \
activity (simply put, feel free to use it in your classroom) as well as \
contact information should you have a concern, criticism or compliment.\"\>",
       StripOnInput->False,
       FontSize->14]},
     {
      StyleBox["\<\"Written by BoB LeSuer\"\>",
       StripOnInput->False,
       FontSize->14,
       FontWeight->Bold]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{2}}}],
   "Column"]]], "Output",
 CellChangeTimes->{
  3.554811561796875*^9, 3.554814857640625*^9, {3.5548149393125*^9, 
   3.554814948859375*^9}, {3.554815161859375*^9, 3.554815238859375*^9}}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.554812084296875*^9, 3.554812470265625*^9}, 
   3.554812739171875*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Activity tab", "Subsubsection",
 CellChangeTimes->{{3.554815354359375*^9, 3.554815356140625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"data", ",", "lm", ",", "subset"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"subset", " ", "=", " ", 
       RowBox[{"If", "[", 
        RowBox[{"useclasses", ",", 
         RowBox[{"ElementData", "[", "whichclass", "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{"lowz", ",", "highz"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"data", " ", "=", " ", 
       RowBox[{"DeleteCases", "[", 
        RowBox[{
         RowBox[{"Quiet", "@", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Thread", "[", 
              RowBox[{"ElementData", "[", 
               RowBox[{"#", ",", 
                RowBox[{"{", 
                 RowBox[{"xaxis", ",", "yaxis", ",", "\"\<Symbol\>\""}], 
                 "}"}]}], "]"}], "]"}], "&"}], ",", "subset"}], "]"}]}], ",", 
         RowBox[{"x_", "/;", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", 
             RowBox[{"x", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "\[Equal]", "Missing"}], 
           "||", 
           RowBox[{
            RowBox[{"Head", "[", 
             RowBox[{"x", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "]"}], "\[Equal]", 
            "Missing"}]}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"data", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}], "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"xaxis", "\[Equal]", "\"\<IonizationEnergies\>\""}], ",", 
         RowBox[{"First", "/@", 
          RowBox[{"data", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ",", 
         RowBox[{"data", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "1"}], "]"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"data", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}], " ", "=", " ", 
       RowBox[{"xaxisfunction", "[", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"data", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}], "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"yaxis", "\[Equal]", "\"\<IonizationEnergies\>\""}], ",", 
         RowBox[{"First", "/@", 
          RowBox[{"data", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "2"}], "]"}], "]"}]}], ",", 
         RowBox[{"data", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "2"}], "]"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"data", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}], "=", 
       RowBox[{"yaxisfunction", "[", 
        RowBox[{"data", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"lm", " ", "=", " ", 
       RowBox[{"If", "[", 
        RowBox[{"fit", ",", 
         RowBox[{"LinearModelFit", "[", 
          RowBox[{
           RowBox[{"data", "[", 
            RowBox[{"[", 
             RowBox[{"All", ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", "x", ",", 
           "x"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{"fit", ",", "\[IndentingNewLine]", 
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"Normal", "[", "lm", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"Min", "[", 
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
            RowBox[{"Max", "[", 
             RowBox[{"data", "[", 
              RowBox[{"[", 
               RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"Epilog", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Tooltip", "[", 
               RowBox[{
                RowBox[{"Point", "[", 
                 RowBox[{"data", "[", 
                  RowBox[{"[", 
                   RowBox[{"#", ",", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], "]"}], 
                ",", 
                RowBox[{"data", "[", 
                 RowBox[{"[", 
                  RowBox[{"#", ",", "3"}], "]"}], "]"}]}], "]"}], "&"}], "/@", 
             RowBox[{"Range", "[", 
              RowBox[{"Length", "[", "data", "]"}], "]"}]}], ")"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Frame", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"True", ",", "True", ",", "False", ",", "False"}], 
            "}"}]}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"xaxis", ",", "yaxis"}], "}"}]}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "plotrange"}], ",", 
          RowBox[{"Axes", "\[Rule]", "False"}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"\"\<y = \>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{
              RowBox[{"lm", "[", "\"\<BestFit\>\"", "]"}], " ", ",", 
              RowBox[{"FormatType", "\[Rule]", "TraditionalForm"}]}], "]"}], 
            "<>", "\"\<\\n\!\(\*SuperscriptBox[\(R\), \(2\)]\):\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"N", "[", 
              RowBox[{"lm", "[", "\"\<RSquared\>\"", "]"}], "]"}], 
             "]"}]}]}]}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Tooltip", "[", 
              RowBox[{
               RowBox[{"data", "[", 
                RowBox[{"[", 
                 RowBox[{"#", ",", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
               RowBox[{"data", "[", 
                RowBox[{"[", 
                 RowBox[{"#", ",", "3"}], "]"}], "]"}]}], "]"}], "&"}], "/@", 
            RowBox[{"Range", "[", 
             RowBox[{"Length", "[", "data", "]"}], "]"}]}], ")"}], ",", 
          RowBox[{"Frame", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"True", ",", "True", ",", "False", ",", "False"}], 
            "}"}]}], ",", 
          RowBox[{"FrameLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"xaxis", ",", "yaxis"}], "}"}]}], ",", 
          RowBox[{"Filling", "\[Rule]", "Axis"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "plotrange"}], ",", 
          RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], 
       "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Tooltip", "[", 
    RowBox[{
     RowBox[{"Style", "[", 
      RowBox[{"\"\<Atom selection\>\"", ",", "12", ",", "Bold"}], "]"}], ",", 
     "\"\<There are two modes of Z selection: select a Z range or use a class \
of compounds.\>\""}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"useclasses", ",", "False", ",", "\"\<Use Classes?\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lowz", ",", "1", ",", "\"\<Smallest Z\>\""}], "}"}], ",", "1", 
     ",", 
     RowBox[{"highz", "-", "5"}], ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", 
      RowBox[{"{", "\"\<Labeled\>\"", "}"}]}], ",", 
     RowBox[{"Enabled", "\[Rule]", 
      RowBox[{"!", "useclasses"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"highz", ",", "102", ",", "\"\<Largest Z\>\""}], "}"}], ",", 
     RowBox[{"lowz", "+", "5"}], ",", "102", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"Enabled", " ", "\[Rule]", " ", 
      RowBox[{"!", "useclasses"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "whichclass", ",", "\"\<Natural\>\"", ",", "\"\<Choose class\>\""}], 
      "}"}], ",", "classes", ",", 
     RowBox[{"Enabled", "\[Rule]", "useclasses"}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"Tooltip", "[", 
    RowBox[{
     RowBox[{"Style", "[", 
      RowBox[{"\"\<Miscellaneous\>\"", ",", "12", ",", "Bold"}], "]"}], ",", 
     "\"\<Choose whether or not to include a linear regression line.  Also, \
when some plots have 1 or two extraneous points, the Automatic mode ignores \
them.\>\""}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Control", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"fit", ",", "False", ",", "\"\<Linear Fit?\>\""}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"True", ",", "False"}], "}"}]}], "}"}], "]"}], ",", 
      "\"\<     \>\"", ",", 
      RowBox[{"Control", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"plotrange", ",", "Automatic", ",", "\"\<Plot Range?\>\""}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Automatic", ",", "All"}], "}"}]}], "}"}], "]"}]}], "}"}], 
    "]"}], ",", "\[IndentingNewLine]", "Delimiter", ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Tooltip", "[", 
    RowBox[{
     RowBox[{"Style", "[", 
      RowBox[{
      "\"\<Axis parameters and function to apply\>\"", ",", "12", ",", 
       "Bold"}], "]"}], ",", 
     "\"\<There are many parameters to choose from.  Unselecting 'Full \
parameter set' gives a list of 10 common parameters.  A log or inverse \
function can be applied to each axis.  Clicking on 'nofunc' gives the data as \
is.\>\""}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "xaxis", ",", "\"\<AtomicNumber\>\"", ",", "\"\<X Parameter\>\""}], 
      "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{"pset", ",", "properties", ",", "partproperties"}], "]"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "PopupMenu"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xaxisfunction", ",", "nofunc"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"nofunc", ",", "log", ",", "inverse"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "yaxis", ",", "\"\<AtomicWeight\>\"", ",", " ", "\"\<Y Parameter\>\""}],
       "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{"pset", ",", "properties", ",", "partproperties"}], "]"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "PopupMenu"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"yaxisfunction", ",", "nofunc"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"nofunc", ",", "log", ",", "inverse"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pset", ",", "True", ",", "\"\<Full Parameter Set?\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"True", ",", "False"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ContinuousAction", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", "Bottom"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Initialization", ":>", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"properties", " ", "=", 
       RowBox[{"{", 
        RowBox[{
        "\"\<AtomicNumber\>\"", ",", "\"\<AtomicWeight\>\"", ",", 
         "\"\<AtomicRadius\>\"", ",", "\"\<CovalentRadius\>\"", ",", 
         "\"\<VanDerWaalsRadius\>\"", ",", "\"\<IonizationEnergies\>\"", ",", 
         "\"\<ElectronAffinity\>\"", ",", "\"\<Electronegativity\>\"", ",", 
         "\"\<BrinellHardness\>\"", ",", "\"\<BulkModulus\>\"", ",", 
         "\"\<Density\>\"", ",", "\"\<MohsHardness\>\"", ",", 
         "\"\<MolarVolume\>\"", ",", "\"\<PoissonRatio\>\"", ",", 
         "\"\<ShearModulus\>\"", ",", "\"\<SoundSpeed\>\"", ",", 
         "\"\<ThermalConductivity\>\"", ",", "\"\<ThermalExpansion\>\"", ",", 
         "\"\<VickersHardness\>\"", ",", "\"\<YoungModulus\>\"", ",", 
         "\"\<AbsoluteBoilingPoint\>\"", ",", "\"\<AbsoluteMeltingPoint\>\"", 
         ",", "\"\<CriticalPressure\>\"", ",", "\"\<CriticalTemperature\>\"", 
         ",", "\"\<FusionHeat\>\"", ",", "\"\<SpecificHeat\>\"", ",", 
         "\"\<VaporizationHeat\>\"", ",", "\"\<ElectricalConductivity\>\"", 
         ",", "\"\<MassMagneticSusceptibility\>\"", ",", 
         "\"\<MolarMagneticSusceptibility\>\"", ",", "\"\<Resistivity\>\"", 
         ",", "\"\<VolumeMagneticSusceptibility\>\"", ",", 
         "\"\<CrustAbundance\>\"", ",", "\"\<HumanAbundance\>\"", ",", 
         "\"\<MeteoriteAbundance\>\"", ",", "\"\<OceanAbundance\>\"", ",", 
         "\"\<SolarAbundance\>\"", ",", "\"\<UniverseAbundance\>\"", ",", 
         "\"\<DiscoveryYear\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"partproperties", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
        "\"\<AtomicNumber\>\"", ",", "\"\<AtomicWeight\>\"", ",", 
         "\"\<AtomicRadius\>\"", ",", "\"\<IonizationEnergies\>\"", ",", 
         "\"\<ElectronAffinity\>\"", ",", "\"\<Electronegativity\>\"", ",", 
         "\"\<Density\>\"", ",", "\"\<AbsoluteBoilingPoint\>\"", ",", 
         "\"\<AbsoluteMeltingPoint\>\"", ",", "\"\<UniverseAbundance\>\"", 
         ",", "\"\<DiscoveryYear\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"classes", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Natural\>\"", ",", "\"\<SBlock\>\"", ",", "\"\<PBlock\>\"", ",", 
         "\"\<DBlock\>\"", ",", "\"\<FBlock\>\"", ",", "\"\<AlkaliMetal\>\"", 
         ",", "\"\<AlkalineEarthMetal\>\"", ",", "\"\<Group13Elements\>\"", 
         ",", "\"\<Group14Elements\>\"", ",", "\"\<Group15Elements\>\"", ",", 
         "\"\<Chalcogen\>\"", ",", "\"\<Halogen\>\"", ",", 
         "\"\<Period4Elements\>\""}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"nofunc", "[", "x_", "]"}], ":=", "x"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"log", "[", "x_", "]"}], ":=", 
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", "x"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"inverse", "[", "x_", "]"}], ":=", 
       SuperscriptBox["x", 
        RowBox[{"-", "1"}]]}], ";"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.554815397265625*^9, 3.55481583746875*^9}, {
  3.557139722109375*^9, 3.557139733953125*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`fit$$ = False, $CellContext`highz$$ = 
    102, $CellContext`lowz$$ = 1, $CellContext`plotrange$$ = 
    Automatic, $CellContext`pset$$ = True, $CellContext`useclasses$$ = 
    False, $CellContext`whichclass$$ = "Natural", $CellContext`xaxis$$ = 
    "AtomicNumber", $CellContext`xaxisfunction$$ = $CellContext`nofunc, \
$CellContext`yaxis$$ = 
    "AtomicWeight", $CellContext`yaxisfunction$$ = $CellContext`nofunc, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[
       Tooltip[
        Style["Atom selection", 12, Bold], 
        "There are two modes of Z selection: select a Z range or use a class \
of compounds."]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`useclasses$$], False, "Use Classes?"}, {
      True, False}}, {{
       Hold[$CellContext`lowz$$], 1, "Smallest Z"}, 1, 
      Dynamic[$CellContext`highz$$ - 5], 1}, {{
       Hold[$CellContext`highz$$], 102, "Largest Z"}, 
      Dynamic[$CellContext`lowz$$ + 5], 102, 1}, {{
       Hold[$CellContext`whichclass$$], "Natural", "Choose class"}, {
      "Natural", "SBlock", "PBlock", "DBlock", "FBlock", "AlkaliMetal", 
       "AlkalineEarthMetal", "Group13Elements", "Group14Elements", 
       "Group15Elements", "Chalcogen", "Halogen", "Period4Elements"}}, {
      Hold[
       Tooltip[
        Style["Miscellaneous", 12, Bold], 
        "Choose whether or not to include a linear regression line.  Also, \
when some plots have 1 or two extraneous points, the Automatic mode ignores \
them."]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`fit$$], False, "Linear Fit?"}, {True, False}}, {{
       Hold[$CellContext`plotrange$$], Automatic, "Plot Range?"}, {
      Automatic, All}}, {
      Hold[
       Row[{
         Manipulate`Place[1], "     ", 
         Manipulate`Place[2]}]], Manipulate`Dump`ThisIsNotAControl}, {
      Hold[
       Tooltip[
        Style["Axis parameters and function to apply", 12, Bold], 
        "There are many parameters to choose from.  Unselecting 'Full \
parameter set' gives a list of 10 common parameters.  A log or inverse \
function can be applied to each axis.  Clicking on 'nofunc' gives the data as \
is."]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`xaxis$$], "AtomicNumber", "X Parameter"}, 
      Dynamic[
       If[$CellContext`pset$$, $CellContext`properties, \
$CellContext`partproperties]]}, {{
       Hold[$CellContext`xaxisfunction$$], $CellContext`nofunc}, \
{$CellContext`nofunc, $CellContext`log, $CellContext`inverse}}, {{
       Hold[$CellContext`yaxis$$], "AtomicWeight", "Y Parameter"}, 
      Dynamic[
       If[$CellContext`pset$$, $CellContext`properties, \
$CellContext`partproperties]]}, {{
       Hold[$CellContext`yaxisfunction$$], $CellContext`nofunc}, \
{$CellContext`nofunc, $CellContext`log, $CellContext`inverse}}, {{
       Hold[$CellContext`pset$$], True, "Full Parameter Set?"}, {
      True, False}}}, Typeset`size$$ = {360., {115., 119.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`useclasses$18586$$ = 
    False, $CellContext`lowz$18587$$ = 0, $CellContext`highz$18588$$ = 
    0, $CellContext`whichclass$18589$$ = 0, $CellContext`fit$18590$$ = 
    False, $CellContext`plotrange$18591$$ = 
    False, $CellContext`xaxisfunction$18592$$ = 
    0, $CellContext`yaxisfunction$18593$$ = 0, $CellContext`pset$18594$$ = 
    False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`fit$$ = False, $CellContext`highz$$ = 
        102, $CellContext`lowz$$ = 1, $CellContext`plotrange$$ = 
        Automatic, $CellContext`pset$$ = True, $CellContext`useclasses$$ = 
        False, $CellContext`whichclass$$ = "Natural", $CellContext`xaxis$$ = 
        "AtomicNumber", $CellContext`xaxisfunction$$ = $CellContext`nofunc, \
$CellContext`yaxis$$ = 
        "AtomicWeight", $CellContext`yaxisfunction$$ = $CellContext`nofunc}, 
      "ControllerVariables" :> {
        Hold[$CellContext`useclasses$$, $CellContext`useclasses$18586$$, 
         False], 
        Hold[$CellContext`lowz$$, $CellContext`lowz$18587$$, 0], 
        Hold[$CellContext`highz$$, $CellContext`highz$18588$$, 0], 
        Hold[$CellContext`whichclass$$, $CellContext`whichclass$18589$$, 0], 
        Hold[$CellContext`fit$$, $CellContext`fit$18590$$, False], 
        Hold[$CellContext`plotrange$$, $CellContext`plotrange$18591$$, False], 
        Hold[$CellContext`xaxisfunction$$, $CellContext`xaxisfunction$18592$$,
          0], 
        Hold[$CellContext`yaxisfunction$$, $CellContext`yaxisfunction$18593$$,
          0], 
        Hold[$CellContext`pset$$, $CellContext`pset$18594$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`data$, $CellContext`lm$, $CellContext`subset$}, \
$CellContext`subset$ = If[$CellContext`useclasses$$, 
           ElementData[$CellContext`whichclass$$], 
           
           Range[$CellContext`lowz$$, $CellContext`highz$$]]; \
$CellContext`data$ = DeleteCases[
           Quiet[
            Map[Thread[
              
              ElementData[#, {$CellContext`xaxis$$, $CellContext`yaxis$$, 
                "Symbol"}]]& , $CellContext`subset$]], 
           Condition[
            Pattern[$CellContext`x, 
             Blank[]], 
            Or[Head[
               Part[$CellContext`x, 1]] == Missing, Head[
               Part[$CellContext`x, 2]] == Missing]]]; 
        Part[$CellContext`data$, All, 1] = 
         If[$CellContext`xaxis$$ == "IonizationEnergies", 
           Map[First, 
            Part[$CellContext`data$, All, 1]], 
           Part[$CellContext`data$, All, 1]]; 
        Part[$CellContext`data$, All, 1] = $CellContext`xaxisfunction$$[
           Part[$CellContext`data$, All, 1]]; 
        Part[$CellContext`data$, All, 2] = 
         If[$CellContext`yaxis$$ == "IonizationEnergies", 
           Map[First, 
            Part[$CellContext`data$, All, 2]], 
           Part[$CellContext`data$, All, 2]]; 
        Part[$CellContext`data$, All, 2] = $CellContext`yaxisfunction$$[
           Part[$CellContext`data$, All, 2]]; $CellContext`lm$ = 
         If[$CellContext`fit$$, 
           LinearModelFit[
            
            Part[$CellContext`data$, All, {1, 
             2}], $CellContext`x, $CellContext`x]]; If[$CellContext`fit$$, 
          Plot[
           Normal[$CellContext`lm$], {$CellContext`x, 
            Min[
             Part[$CellContext`data$, All, 1]], 
            Max[
             Part[$CellContext`data$, All, 1]]}, Epilog -> Map[Tooltip[
              Point[
               Part[$CellContext`data$, #, {1, 2}]], 
              Part[$CellContext`data$, #, 3]]& , 
             Range[
              Length[$CellContext`data$]]], 
           Frame -> {True, True, False, False}, 
           FrameLabel -> {$CellContext`xaxis$$, $CellContext`yaxis$$}, 
           PlotRange -> $CellContext`plotrange$$, Axes -> False, PlotLabel -> 
           StringJoin["y = ", 
             ToString[
              $CellContext`lm$["BestFit"], FormatType -> TraditionalForm], 
             "\n\!\(\*SuperscriptBox[\(R\), \(2\)]\):", 
             ToString[
              N[
               $CellContext`lm$["RSquared"]]]]], 
          ListPlot[
           Map[Tooltip[
             Part[$CellContext`data$, #, {1, 2}], 
             Part[$CellContext`data$, #, 3]]& , 
            Range[
             Length[$CellContext`data$]]], 
           Frame -> {True, True, False, False}, 
           FrameLabel -> {$CellContext`xaxis$$, $CellContext`yaxis$$}, 
           Filling -> Axis, PlotRange -> $CellContext`plotrange$$, Axes -> 
           False]]], "Specifications" :> {
        Tooltip[
         Style["Atom selection", 12, Bold], 
         "There are two modes of Z selection: select a Z range or use a class \
of compounds."], {{$CellContext`useclasses$$, False, "Use Classes?"}, {
         True, False}}, {{$CellContext`lowz$$, 1, "Smallest Z"}, 1, 
         Dynamic[$CellContext`highz$$ - 5], 1, Appearance -> {"Labeled"}, 
         Enabled -> Dynamic[
           Not[$CellContext`useclasses$$]]}, {{$CellContext`highz$$, 102, 
          "Largest Z"}, 
         Dynamic[$CellContext`lowz$$ + 5], 102, 1, Appearance -> "Labeled", 
         Enabled -> Dynamic[
           Not[$CellContext`useclasses$$]]}, {{$CellContext`whichclass$$, 
          "Natural", "Choose class"}, {
         "Natural", "SBlock", "PBlock", "DBlock", "FBlock", "AlkaliMetal", 
          "AlkalineEarthMetal", "Group13Elements", "Group14Elements", 
          "Group15Elements", "Chalcogen", "Halogen", "Period4Elements"}, 
         Enabled -> Dynamic[$CellContext`useclasses$$]}, Delimiter, 
        Tooltip[
         Style["Miscellaneous", 12, Bold], 
         "Choose whether or not to include a linear regression line.  Also, \
when some plots have 1 or two extraneous points, the Automatic mode ignores \
them."], {{$CellContext`fit$$, False, "Linear Fit?"}, {True, False}, 
         ControlPlacement -> 
         1}, {{$CellContext`plotrange$$, Automatic, "Plot Range?"}, {
         Automatic, All}, ControlPlacement -> 2}, 
        Row[{
          Manipulate`Place[1], "     ", 
          Manipulate`Place[2]}], Delimiter, 
        Tooltip[
         Style["Axis parameters and function to apply", 12, Bold], 
         "There are many parameters to choose from.  Unselecting 'Full \
parameter set' gives a list of 10 common parameters.  A log or inverse \
function can be applied to each axis.  Clicking on 'nofunc' gives the data as \
is."], {{$CellContext`xaxis$$, "AtomicNumber", "X Parameter"}, 
         Dynamic[
          
          If[$CellContext`pset$$, $CellContext`properties, \
$CellContext`partproperties]], ControlType -> 
         PopupMenu}, {{$CellContext`xaxisfunction$$, $CellContext`nofunc}, \
{$CellContext`nofunc, $CellContext`log, $CellContext`inverse}}, \
{{$CellContext`yaxis$$, "AtomicWeight", "Y Parameter"}, 
         Dynamic[
          
          If[$CellContext`pset$$, $CellContext`properties, \
$CellContext`partproperties]], ControlType -> 
         PopupMenu}, {{$CellContext`yaxisfunction$$, $CellContext`nofunc}, \
{$CellContext`nofunc, $CellContext`log, $CellContext`inverse}}, \
{{$CellContext`pset$$, True, "Full Parameter Set?"}, {True, False}}}, 
      "Options" :> {ContinuousAction -> False, ControlPlacement -> Bottom}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{407., {299., 304.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`properties = {
         "AtomicNumber", "AtomicWeight", "AtomicRadius", "CovalentRadius", 
          "VanDerWaalsRadius", "IonizationEnergies", "ElectronAffinity", 
          "Electronegativity", "BrinellHardness", "BulkModulus", "Density", 
          "MohsHardness", "MolarVolume", "PoissonRatio", "ShearModulus", 
          "SoundSpeed", "ThermalConductivity", "ThermalExpansion", 
          "VickersHardness", "YoungModulus", "AbsoluteBoilingPoint", 
          "AbsoluteMeltingPoint", "CriticalPressure", "CriticalTemperature", 
          "FusionHeat", "SpecificHeat", "VaporizationHeat", 
          "ElectricalConductivity", "MassMagneticSusceptibility", 
          "MolarMagneticSusceptibility", "Resistivity", 
          "VolumeMagneticSusceptibility", "CrustAbundance", "HumanAbundance", 
          "MeteoriteAbundance", "OceanAbundance", "SolarAbundance", 
          "UniverseAbundance", 
          "DiscoveryYear"}; $CellContext`partproperties = {
         "AtomicNumber", "AtomicWeight", "AtomicRadius", "IonizationEnergies",
           "ElectronAffinity", "Electronegativity", "Density", 
          "AbsoluteBoilingPoint", "AbsoluteMeltingPoint", "UniverseAbundance",
           "DiscoveryYear"}; $CellContext`classes = {
         "Natural", "SBlock", "PBlock", "DBlock", "FBlock", "AlkaliMetal", 
          "AlkalineEarthMetal", "Group13Elements", "Group14Elements", 
          "Group15Elements", "Chalcogen", "Halogen", 
          "Period4Elements"}; $CellContext`nofunc[
          Pattern[$CellContext`x, 
           Blank[]]] := $CellContext`x; $CellContext`log[
          Pattern[$CellContext`x, 
           Blank[]]] := Log[10, $CellContext`x]; $CellContext`inverse[
          Pattern[$CellContext`x, 
           Blank[]]] := $CellContext`x^(-1); Null}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.554815567828125*^9, 3.55481569640625*^9, 3.5548158391875*^9, {
   3.55713972346875*^9, 3.557139734859375*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example tab", "Subsubsection",
 CellChangeTimes->{{3.55481254634375*^9, 3.55481254934375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Panel", "[", 
  RowBox[{"Column", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Sample Exercises\>\"", ",", "Bold", ",", "20"}], "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<Exercise #1\\n(1) PREDICT what the plot of atomic radius versus \
atomic number will look like for the elements in the 4th row of the periodic \
table.\\n(2) On the Activity tab, make sure the \!\(\*
StyleBox[\"Use\",
FontVariations->{\"Underline\"->True}]\)\!\(\*
StyleBox[\" \",
FontVariations->{\"Underline\"->True}]\)\!\(\*
StyleBox[\"classes\",
FontVariations->{\"Underline\"->True}]\) checkbox is selected in the Atom \
Selection pane, then select \!\(\*
StyleBox[\"Period4elements\",
FontVariations->{\"Underline\"->True}]\) from the class menu.\\n(3) Select \!\
\(\*
StyleBox[\"AtomicNumber\",
FontVariations->{\"Underline\"->True}]\) for the x parameter and \!\(\*
StyleBox[\"AtomicRadius\",
FontVariations->{\"Underline\"->True}]\) for the y parameter.\\n(4) DESCRIBE \
what you observe.  Was your prediction in step 1 correct?\\n(5) EXPLAIN the \
trend.  If you need help, look in a chemistry textbook for the shielding \
effect.  You can also do a web search on that topic.\>\"", ",", "14"}], "]"}],
       ",", "\[IndentingNewLine]", 
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<Exercise #2\\n(1) PREDICT what the plot of atomic radius versus \
atomic number will look like for the elements in group 17: the \
halogens.\\n(2) On the Activity tab, change the selection in the class menu \
to halogen.\\n(3) DESCRIBE what you observe.  Was your prediction in step 1 \
correct?\\n(5) EXPLAIN the trend.  Can you combine the results from these two \
exercises to explain how the shielding effect influences the atomic radius?\>\
\"", ",", "14"}], "]"}]}], "}"}], ",", 
    RowBox[{"Dividers", "\[Rule]", "Center"}], ",", 
    RowBox[{"Spacings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "1"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.554812782109375*^9, 3.554812793859375*^9}, {
  3.554812835171875*^9, 3.554812838359375*^9}, {3.55481302196875*^9, 
  3.554813055453125*^9}, {3.554813090921875*^9, 3.554813091109375*^9}, {
  3.554813122390625*^9, 3.554813576375*^9}, {3.554814706671875*^9, 
  3.5548147131875*^9}}],

Cell[BoxData[
 PanelBox[
  TagBox[GridBox[{
     {
      StyleBox["\<\"Sample Exercises\"\>",
       StripOnInput->False,
       FontSize->20,
       FontWeight->Bold]},
     {
      StyleBox["\<\"Exercise #1\\n(1) PREDICT what the plot of atomic radius \
versus atomic number will look like for the elements in the 4th row of the \
periodic table.\\n(2) On the Activity tab, make sure the \
\\!\\(\\*\\nStyleBox[\\\"Use\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\
\\)\\!\\(\\*\\nStyleBox[\\\" \
\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\)\\!\\(\\*\\nStyleBox[\\\"\
classes\\\",\\nFontVariations->{\\\"Underline\\\"->True}]\\) checkbox is \
selected in the Atom Selection pane, then select \
\\!\\(\\*\\nStyleBox[\\\"Period4elements\\\",\\nFontVariations->{\\\"\
Underline\\\"->True}]\\) from the class menu.\\n(3) Select \
\\!\\(\\*\\nStyleBox[\\\"AtomicNumber\\\",\\nFontVariations->{\\\"Underline\\\
\"->True}]\\) for the x parameter and \\!\\(\\*\\nStyleBox[\\\"AtomicRadius\\\
\",\\nFontVariations->{\\\"Underline\\\"->True}]\\) for the y \
parameter.\\n(4) DESCRIBE what you observe.  Was your prediction in step 1 \
correct?\\n(5) EXPLAIN the trend.  If you need help, look in a chemistry \
textbook for the shielding effect.  You can also do a web search on that \
topic.\"\>",
       StripOnInput->False,
       FontSize->14]},
     {
      StyleBox["\<\"Exercise #2\\n(1) PREDICT what the plot of atomic radius \
versus atomic number will look like for the elements in group 17: the \
halogens.\\n(2) On the Activity tab, change the selection in the class menu \
to halogen.\\n(3) DESCRIBE what you observe.  Was your prediction in step 1 \
correct?\\n(5) EXPLAIN the trend.  Can you combine the results from these two \
exercises to explain how the shielding effect influences the atomic radius?\"\
\>",
       StripOnInput->False,
       FontSize->14]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxDividers->{
     "Columns" -> {False, {True}, False}, "Rows" -> {False, {True}, False}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
   "Column"]]], "Output",
 CellChangeTimes->{{3.55481312575*^9, 3.554813183109375*^9}, 
   3.5548132179375*^9, {3.55481326575*^9, 3.55481333859375*^9}, 
   3.554813513328125*^9, 3.5548135770625*^9, 3.55481471359375*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Legal tab", "Subsubsection",
 CellChangeTimes->{{3.554812566640625*^9, 3.55481256765625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Panel", "[", 
  RowBox[{"Column", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<Who did this? How? and Why?\>\"", ",", "Bold", ",", "20"}], "]"}],
       ",", "\[IndentingNewLine]", 
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<      BoB LeSuer; using Mathematica's FreeCDF; the tools were \
there.  I'm of the mindset that Chemistry is a far more tactile, visual and \
dynamic science than can be represented in a static textbook.\>\"", ",", 
        "14"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Can I use it?\>\"", ",", "Bold", ",", "20"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<      Yes, please do.  The activity is freely available for use.  \
Wolfram's FreeCDF licensing terms can be found at the link below.  I'm happy \
to share the code with anyone interested; simply contact me.\>\"", ",", 
        "14"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Links\>\"", ",", "Bold", ",", "20"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{"Hyperlink", "[", 
         RowBox[{
         "\"\<Wolfram FreeCDF licensing terms\>\"", ",", 
          "\"\<Http://www.wolfram.com/cdf/adopting-cdf/licensing-options.html\
\>\""}], "]"}], ",", "14"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{"Hyperlink", "[", 
         RowBox[{
         "\"\<My contact information\>\"", ",", 
          "\"\<http://www.csu.edu/chemistryandphysics/facultylesuer.htm\>\""}]\
, "]"}], ",", "14"}], "]"}]}], "\[IndentingNewLine]", "}"}], ",", 
    RowBox[{"Spacings", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Automatic", ",", "1"}], "}"}]}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.554813640125*^9, 3.554813644359375*^9}, {
  3.554813734890625*^9, 3.554814121921875*^9}, {3.5548141535625*^9, 
  3.5548142061875*^9}, {3.554814285859375*^9, 3.5548144359375*^9}, {
  3.5548144729375*^9, 3.55481451165625*^9}, {3.554814579890625*^9, 
  3.554814641625*^9}, {3.554814683546875*^9, 3.554814697078125*^9}, {
  3.554814734046875*^9, 3.554814745265625*^9}}],

Cell[BoxData[
 PanelBox[
  TagBox[GridBox[{
     {
      StyleBox["\<\"Who did this? How? and Why?\"\>",
       StripOnInput->False,
       FontSize->20,
       FontWeight->Bold]},
     {
      StyleBox["\<\"      BoB LeSuer; using Mathematica's FreeCDF; the tools \
were there.  I'm of the mindset that Chemistry is a far more tactile, visual \
and dynamic science than can be represented in a static textbook.\"\>",
       StripOnInput->False,
       FontSize->14]},
     {
      StyleBox["\<\"Can I use it?\"\>",
       StripOnInput->False,
       FontSize->20,
       FontWeight->Bold]},
     {
      StyleBox["\<\"      Yes, please do.  The activity is freely available \
for use.  Wolfram's FreeCDF licensing terms can be found at the link below.  \
I'm happy to share the code with anyone interested; simply contact me.\"\>",
       StripOnInput->False,
       FontSize->14]},
     {
      StyleBox["\<\"Links\"\>",
       StripOnInput->False,
       FontSize->20,
       FontWeight->Bold]},
     {
      StyleBox[
       TagBox[
        ButtonBox[
         PaneSelectorBox[{False->"\<\"Wolfram FreeCDF licensing terms\"\>", 
          True->
          
          StyleBox["\<\"Wolfram FreeCDF licensing terms\"\>", 
           "HyperlinkActive"]}, Dynamic[
           CurrentValue["MouseOver"]],
          BaseStyle->{"Hyperlink"},
          BaselinePosition->Baseline,
          FrameMargins->0,
          ImageSize->Automatic],
         BaseStyle->"Hyperlink",
         ButtonData->{
           URL[
           "Http://www.wolfram.com/cdf/adopting-cdf/licensing-options.html"], 
           None},
         ButtonNote->
          "Http://www.wolfram.com/cdf/adopting-cdf/licensing-options.html"],
        Annotation[#, 
         "Http://www.wolfram.com/cdf/adopting-cdf/licensing-options.html", 
         "Hyperlink"]& ],
       StripOnInput->False,
       FontSize->14]},
     {
      StyleBox[
       TagBox[
        ButtonBox[
         PaneSelectorBox[{False->"\<\"My contact information\"\>", True->
          StyleBox["\<\"My contact information\"\>", "HyperlinkActive"]}, 
          Dynamic[
           CurrentValue["MouseOver"]],
          BaseStyle->{"Hyperlink"},
          BaselinePosition->Baseline,
          FrameMargins->0,
          ImageSize->Automatic],
         BaseStyle->"Hyperlink",
         ButtonData->{
           URL["http://www.csu.edu/chemistryandphysics/facultylesuer.htm"], 
           None},
         ButtonNote->
          "http://www.csu.edu/chemistryandphysics/facultylesuer.htm"],
        Annotation[#, 
         "http://www.csu.edu/chemistryandphysics/facultylesuer.htm", 
         "Hyperlink"]& ],
       StripOnInput->False,
       FontSize->14]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{"Columns" -> {{Automatic}}, "Rows" -> {{1}}}],
   "Column"]]], "Output",
 CellChangeTimes->{{3.554814594109375*^9, 3.55481462265625*^9}, {
  3.5548146945*^9, 3.554814697671875*^9}, {3.5548147394375*^9, 
  3.554814746125*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{913, 806},
WindowMargins->{{Automatic, 122}, {Automatic, 2}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 132, 2, 83, "Title"],
Cell[CellGroupData[{
Cell[736, 28, 25490, 538, 2341, "Input"],
Cell[26229, 568, 20504, 425, 717, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46770, 998, 96, 1, 27, "Subsubsection"],
Cell[46869, 1001, 124, 2, 31, "Input"],
Cell[46996, 1005, 96, 1, 31, "Input"],
Cell[47095, 1008, 117, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[47237, 1014, 140, 2, 31, "Input"],
Cell[47380, 1018, 1802, 29, 126, "Output"]
}, Open  ]],
Cell[49197, 1050, 137, 2, 31, "Input"],
Cell[CellGroupData[{
Cell[49359, 1056, 394, 10, 31, "Input"],
Cell[49756, 1068, 599, 12, 21, "Message"],
Cell[50358, 1082, 598, 12, 21, "Message"],
Cell[50959, 1096, 641, 12, 21, "Message"],
Cell[51603, 1110, 535, 11, 21, "Message"],
Cell[52141, 1123, 249, 6, 30, "Output"]
}, Open  ]],
Cell[52405, 1132, 589, 11, 52, "Input"],
Cell[CellGroupData[{
Cell[53019, 1147, 217, 5, 31, "Input"],
Cell[53239, 1154, 76, 1, 30, "Output"]
}, Open  ]],
Cell[53330, 1158, 98, 1, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[53465, 1164, 102, 1, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[53592, 1169, 1454, 28, 232, "Input"],
Cell[55049, 1199, 1432, 32, 223, "Output"]
}, Open  ]],
Cell[56496, 1234, 118, 2, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[56651, 1241, 103, 1, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[56779, 1246, 15154, 365, 1254, "Input"],
Cell[71936, 1613, 13160, 255, 620, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[85145, 1874, 100, 1, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[85270, 1879, 2429, 50, 332, "Input"],
Cell[87702, 1931, 2400, 47, 315, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[90151, 1984, 99, 1, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[90275, 1989, 2323, 50, 272, "Input"],
Cell[92601, 2041, 3070, 86, 273, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
